<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_AT">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Ein einfacher, benutzerfreundlicher Jabber/XMPP client</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Lizenz:</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Quellcode online ansehen</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>Probleme melden</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation>Kontosicherheit</translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation type="vanished">Anzeigen des Kennworts ausschalten</translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation type="vanished">QR-Code und Kennwort ausblenden</translation>
    </message>
    <message>
        <source>Allow to add additional devices using the login QR code but never show the password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t show password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Neither allow to add additional devices using the login QR code nor show the password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t expose password in any way</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>Konto auf ein anderes Gerät übertragen</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>Scannen Sie den QR-Code oder geben Sie die Anmeldedaten als Text auf einem anderen Gerät ein, um sich dort anzumelden.

Achtung!
Zeigen Sie diesen QR-Code niemals anderen Personen. Dies würde unbegrenzten Zugang zu Ihrem Konto ermöglichen!</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Kennwort:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>QR-Code ausblenden</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>Als QR-Code anzeigen</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>Text verstecken</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>Als Text anzeigen</translation>
    </message>
    <message>
        <source>Copy JID</source>
        <translation type="vanished">JID kopieren</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Kennwort kopieren</translation>
    </message>
    <message>
        <source>Copy chat address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Kennwort ändern</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Aktuelles Kennwort:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Neues Kennwort:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Neues Kennwort (wiederholen):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>Die eingegebenen Kennwörter stimmen nicht überein.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>Das aktuelle Kennwort ist ungültig.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation type="vanished">Sie müssen verbunden sein, um ihr Passwort zu ändern.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Wenn Sie ihr Kennwort ändern, mußt du es im Anschluss auf allen Geräten neu eingeben.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Password changed successfully</source>
        <translation>Kennwort wurde geändert</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation>Ändern des Kennworts fehlgeschlagen: %1</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Copy Message</source>
        <translation type="vanished">Nachricht kopieren</translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="vanished">Nachricht bearbeiten</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>Spoiler</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation>Nachricht kopieren</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation>Nachricht ändern</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation>Download-URL kopieren</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation>Nachricht zitieren</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation type="vanished">Nachricht verfassen</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Eine Datei wählen</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Bild</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Audio</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Dokument</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Andere Datei</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Versteckte Nachricht senden</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation type="vanished">Titel für versteckte Nachricht</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Schließen</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Suche nach oben</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Suche nach unten</translation>
    </message>
    <message>
        <source>Close message search bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPageSendingPane</name>
    <message>
        <source>Spoiler hint</source>
        <translation type="unfinished">Titel für versteckte Nachricht</translation>
    </message>
    <message>
        <source>Close spoiler hint field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compose message</source>
        <translation>Nachricht verfassen</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Sehr niedrig</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Sehr hoch</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Konstante Bitrate</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>ConnectionSettings</name>
    <message>
        <source>Connection settings</source>
        <translation>Verbindungseinstellungen</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Connection settings could not be changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection settings changed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CustomConnectionSettings</name>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The hostname must not contain blank spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Don&apos;t expose your password in any way</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will neither be shown as plain text nor included in the login QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Consider storing the password somewhere else if you want to use your account on another device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t expose password in any way</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Don&apos;t show your password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be shown anymore but still exposed via the login QR code.
You won&apos;t be able to see your password again because this action cannot be undone!
Consider storing the password somewhere else if you want to use your account on another device without the login QR code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t show password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>Datei konnte nicht gespeichert werden: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Herunterladen fehlgeschlagen: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation type="vanished">Favoriten</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="vanished">Menschen</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation type="vanished">Natur</translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="vanished">Essen</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation type="vanished">Aktivitäten</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="vanished">Reisen</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation type="vanished">Gegenstände</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation type="vanished">Zeichen</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation type="vanished">Flaggen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Suche</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation type="vanished">Emoji suchen</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Wähle einen Chat um zu beginnen</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Datei wählen</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>Go to parent folder</source>
        <translation type="vanished">In übergeordneten Ordner wechseln</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Schließen</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Log out</source>
        <translation type="vanished">Abmelden</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Freunde einladen</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Einladungslink wurde in die Zwischenablage kopiert</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>Der Link wird nach Aufbau der Verbindung geöffnet.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation></translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Mit deinem XMPP-Account anmelden</translation>
    </message>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">Deine Jabber-ID:</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">Dein Passwort:</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Verbinden …</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Verbinden</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Falsche Zugangsdaten.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">Server nicht erreichbar. Überprüfen sie ihrer Internetverbindung.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">Dieser Server unterstützt keine sicheren Verbindungen.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">Fehler bei der Herstellung einer sicheren Verbindung.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">Konnte den Servernamen nicht auflösen. Bitte überprüfen sie Ihre Jabber-ID.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">Konnte nicht mit dem Server verbinden.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">Authentifizierungsprotokolle nicht vom Server unterstützt.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">Ein unbekannter Fehler ist aufgetreten: Sehen Sie die Logdatei für mehr Details ein.</translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished">Verbindungseinstellungen</translation>
    </message>
</context>
<context>
    <name>LoginSettingsPage</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished">Verbindungseinstellungen</translation>
    </message>
    <message>
        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable custom connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Audio</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished">Versteckt</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Konnte Nachricht nicht versenden, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">Konnte Nachricht nicht korrigieren, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Versteckt</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Nachricht konnte nicht gesendet werden.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>Nachrichtenkorrektur schlug fehl.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Image</source>
        <translation type="obsolete">Bild</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="obsolete">Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="obsolete">Video</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Initializing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Invalid username or password.</source>
        <translation type="unfinished">Falsche Zugangsdaten.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation>Server nicht erreichbar. Überprüfen Sie die Internetverbindung.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation>Dieser Server unterstützt keine sicheren Verbindungen.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation>Fehler bei der Herstellung einer sicheren Verbindung.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="obsolete">Konnte nicht mit dem Server verbinden.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation>Authentifizierungsprotokolle nicht vom Server unterstützt.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is typing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 paused typing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeOnboardingPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This QR code is not a valid login QR code.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeScanner</name>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation type="vanished">Passwort erfolgreich geändert.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="vanished">Änderung des Passworts ist fehlgeschlagen: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation>Neuen Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="obsolete">Versteckt</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Connecting…</source>
        <translation>Verbinden…</translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation></translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Neuen Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Delete contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Caption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation>Kennwort ändern</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure the hostname and port to connect to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on another device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="obsolete">Passwort ändern</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Einstellungen</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Nachricht konnte nicht gesendet werden.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
